feast.value_type — Feast 0.3.2 documentation

# Source code for feast.value_type

    # Copyright 2019 The Feast Authors
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    #     https://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing, software
    # distributed under the License is distributed on an "AS IS" BASIS,
    # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    # See the License for the specific language governing permissions and
    # limitations under the License.

    import enum

    class ValueType(enum.Enum):
        """
        Feature value type. Used to define data types in Feature Sets.
        """

        UNKNOWN = 0
        BYTES = 1
        STRING = 2
        INT32 = 3
        INT64 = 4
        DOUBLE = 5
        FLOAT = 6
        BOOL = 7
        BYTES_LIST = 11
        STRING_LIST = 12
        INT32_LIST = 13
        INT64_LIST = 14
        DOUBLE_LIST = 15
        FLOAT_LIST = 16
        BOOL_LIST = 17